Index: Source/web/ServiceWorkerGlobalScopeProxy.h |
diff --git a/Source/web/ServiceWorkerGlobalScopeProxy.h b/Source/web/ServiceWorkerGlobalScopeProxy.h |
index 3ebd55b30901b173f9e3d8962aec284183d02eac..c29fc1397cfbca97de0b78772fcb90d9471bfbf5 100644 |
--- a/Source/web/ServiceWorkerGlobalScopeProxy.h |
+++ b/Source/web/ServiceWorkerGlobalScopeProxy.h |
@@ -57,7 +57,7 @@ class WebServiceWorkerRequest; |
// e.g. onfetch. |
// |
// An instance of this class is supposed to outlive until |
// workerThreadTerminated() is called by its corresponding |
// WorkerGlobalScope. |
class ServiceWorkerGlobalScopeProxy final |
: public WebServiceWorkerContextProxy |
@@ -89,7 +89,7 @@ public: |
virtual void workerGlobalScopeStarted(WorkerGlobalScope*) override; |
virtual void workerGlobalScopeClosed() override; |
virtual void willDestroyWorkerGlobalScope() override; |
- virtual void workerThreadTerminated() override; |
+ virtual void workerScriptTerminated() override; |
private: |
ServiceWorkerGlobalScopeProxy(WebEmbeddedWorkerImpl&, Document&, WebServiceWorkerContextClient&); |
@@ -57,7 +57,7 @@ class WebServiceWorkerRequest; |
// |
// An instance of this class is supposed to outlive until |
-// workerThreadTerminated() is called by its corresponding |
+// workerScriptTerminated() is called by its corresponding |
// WorkerGlobalScope. |
class ServiceWorkerGlobalScopeProxy final |